"use strict";

var _powerAssert = _interopRequireDefault(require("power-assert"));

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _logger = _interopRequireDefault(require("./logger.js"));

var _icoGenerator = _interopRequireWildcard(require("./ico-generator.js"));

var _rewire = _interopRequireDefault(require("rewire"));

var _powerAssertVisitorKeys = "{\"ArrayExpression\":[\"elements\"],\"AssignmentExpression\":[\"left\",\"right\"],\"BinaryExpression\":[\"left\",\"right\"],\"InterpreterDirective\":[],\"Directive\":[\"value\"],\"DirectiveLiteral\":[],\"BlockStatement\":[\"directives\",\"body\"],\"BreakStatement\":[\"label\"],\"CallExpression\":[\"callee\",\"arguments\",\"typeParameters\",\"typeArguments\"],\"CatchClause\":[\"param\",\"body\"],\"ConditionalExpression\":[\"test\",\"consequent\",\"alternate\"],\"ContinueStatement\":[\"label\"],\"DebuggerStatement\":[],\"DoWhileStatement\":[\"test\",\"body\"],\"EmptyStatement\":[],\"ExpressionStatement\":[\"expression\"],\"File\":[\"program\"],\"ForInStatement\":[\"left\",\"right\",\"body\"],\"ForStatement\":[\"init\",\"test\",\"update\",\"body\"],\"FunctionDeclaration\":[\"id\",\"params\",\"body\",\"returnType\",\"typeParameters\"],\"FunctionExpression\":[\"id\",\"params\",\"body\",\"returnType\",\"typeParameters\"],\"Identifier\":[\"typeAnnotation\"],\"IfStatement\":[\"test\",\"consequent\",\"alternate\"],\"LabeledStatement\":[\"label\",\"body\"],\"StringLiteral\":[],\"NumericLiteral\":[],\"NullLiteral\":[],\"BooleanLiteral\":[],\"RegExpLiteral\":[],\"LogicalExpression\":[\"left\",\"right\"],\"MemberExpression\":[\"object\",\"property\"],\"NewExpression\":[\"callee\",\"arguments\",\"typeParameters\",\"typeArguments\"],\"Program\":[\"directives\",\"body\"],\"ObjectExpression\":[\"properties\"],\"ObjectMethod\":[\"key\",\"params\",\"body\",\"decorators\",\"returnType\",\"typeParameters\"],\"ObjectProperty\":[\"key\",\"value\",\"decorators\"],\"RestElement\":[\"argument\",\"typeAnnotation\"],\"ReturnStatement\":[\"argument\"],\"SequenceExpression\":[\"expressions\"],\"SwitchCase\":[\"test\",\"consequent\"],\"SwitchStatement\":[\"discriminant\",\"cases\"],\"ThisExpression\":[],\"ThrowStatement\":[\"argument\"],\"TryStatement\":[\"block\",\"handler\",\"finalizer\"],\"UnaryExpression\":[\"argument\"],\"UpdateExpression\":[\"argument\"],\"VariableDeclaration\":[\"declarations\"],\"VariableDeclarator\":[\"id\",\"init\"],\"WhileStatement\":[\"test\",\"body\"],\"WithStatement\":[\"object\",\"body\"],\"AssignmentPattern\":[\"left\",\"right\"],\"ArrayPattern\":[\"elements\",\"typeAnnotation\"],\"ArrowFunctionExpression\":[\"params\",\"body\",\"returnType\",\"typeParameters\"],\"ClassBody\":[\"body\"],\"ClassDeclaration\":[\"id\",\"body\",\"superClass\",\"mixins\",\"typeParameters\",\"superTypeParameters\",\"implements\",\"decorators\"],\"ClassExpression\":[\"id\",\"body\",\"superClass\",\"mixins\",\"typeParameters\",\"superTypeParameters\",\"implements\",\"decorators\"],\"ExportAllDeclaration\":[\"source\"],\"ExportDefaultDeclaration\":[\"declaration\"],\"ExportNamedDeclaration\":[\"declaration\",\"specifiers\",\"source\"],\"ExportSpecifier\":[\"local\",\"exported\"],\"ForOfStatement\":[\"left\",\"right\",\"body\"],\"ImportDeclaration\":[\"specifiers\",\"source\"],\"ImportDefaultSpecifier\":[\"local\"],\"ImportNamespaceSpecifier\":[\"local\"],\"ImportSpecifier\":[\"local\",\"imported\"],\"MetaProperty\":[\"meta\",\"property\"],\"ClassMethod\":[\"key\",\"params\",\"body\",\"decorators\",\"returnType\",\"typeParameters\"],\"ObjectPattern\":[\"properties\",\"typeAnnotation\"],\"SpreadElement\":[\"argument\"],\"Super\":[],\"TaggedTemplateExpression\":[\"tag\",\"quasi\"],\"TemplateElement\":[],\"TemplateLiteral\":[\"quasis\",\"expressions\"],\"YieldExpression\":[\"argument\"],\"AnyTypeAnnotation\":[],\"ArrayTypeAnnotation\":[\"elementType\"],\"BooleanTypeAnnotation\":[],\"BooleanLiteralTypeAnnotation\":[],\"NullLiteralTypeAnnotation\":[],\"ClassImplements\":[\"id\",\"typeParameters\"],\"DeclareClass\":[\"id\",\"typeParameters\",\"extends\",\"mixins\",\"implements\",\"body\"],\"DeclareFunction\":[\"id\"],\"DeclareInterface\":[\"id\",\"typeParameters\",\"extends\",\"mixins\",\"implements\",\"body\"],\"DeclareModule\":[\"id\",\"body\"],\"DeclareModuleExports\":[\"typeAnnotation\"],\"DeclareTypeAlias\":[\"id\",\"typeParameters\",\"right\"],\"DeclareOpaqueType\":[\"id\",\"typeParameters\",\"supertype\"],\"DeclareVariable\":[\"id\"],\"DeclareExportDeclaration\":[\"declaration\",\"specifiers\",\"source\"],\"DeclareExportAllDeclaration\":[\"source\"],\"DeclaredPredicate\":[\"value\"],\"ExistsTypeAnnotation\":[],\"FunctionTypeAnnotation\":[\"typeParameters\",\"params\",\"rest\",\"returnType\"],\"FunctionTypeParam\":[\"name\",\"typeAnnotation\"],\"GenericTypeAnnotation\":[\"id\",\"typeParameters\"],\"InferredPredicate\":[],\"InterfaceExtends\":[\"id\",\"typeParameters\"],\"InterfaceDeclaration\":[\"id\",\"typeParameters\",\"extends\",\"mixins\",\"implements\",\"body\"],\"InterfaceTypeAnnotation\":[\"extends\",\"body\"],\"IntersectionTypeAnnotation\":[\"types\"],\"MixedTypeAnnotation\":[],\"EmptyTypeAnnotation\":[],\"NullableTypeAnnotation\":[\"typeAnnotation\"],\"NumberLiteralTypeAnnotation\":[],\"NumberTypeAnnotation\":[],\"ObjectTypeAnnotation\":[\"properties\",\"indexers\",\"callProperties\",\"internalSlots\"],\"ObjectTypeInternalSlot\":[\"id\",\"value\",\"optional\",\"static\",\"method\"],\"ObjectTypeCallProperty\":[\"value\"],\"ObjectTypeIndexer\":[\"id\",\"key\",\"value\",\"variance\"],\"ObjectTypeProperty\":[\"key\",\"value\",\"variance\"],\"ObjectTypeSpreadProperty\":[\"argument\"],\"OpaqueType\":[\"id\",\"typeParameters\",\"supertype\",\"impltype\"],\"QualifiedTypeIdentifier\":[\"id\",\"qualification\"],\"StringLiteralTypeAnnotation\":[],\"StringTypeAnnotation\":[],\"ThisTypeAnnotation\":[],\"TupleTypeAnnotation\":[\"types\"],\"TypeofTypeAnnotation\":[\"argument\"],\"TypeAlias\":[\"id\",\"typeParameters\",\"right\"],\"TypeAnnotation\":[\"typeAnnotation\"],\"TypeCastExpression\":[\"expression\",\"typeAnnotation\"],\"TypeParameter\":[\"bound\",\"default\",\"variance\"],\"TypeParameterDeclaration\":[\"params\"],\"TypeParameterInstantiation\":[\"params\"],\"UnionTypeAnnotation\":[\"types\"],\"Variance\":[],\"VoidTypeAnnotation\":[],\"JSXAttribute\":[\"name\",\"value\"],\"JSXClosingElement\":[\"name\"],\"JSXElement\":[\"openingElement\",\"children\",\"closingElement\"],\"JSXEmptyExpression\":[],\"JSXExpressionContainer\":[\"expression\"],\"JSXSpreadChild\":[\"expression\"],\"JSXIdentifier\":[],\"JSXMemberExpression\":[\"object\",\"property\"],\"JSXNamespacedName\":[\"namespace\",\"name\"],\"JSXOpeningElement\":[\"name\",\"attributes\"],\"JSXSpreadAttribute\":[\"argument\"],\"JSXText\":[],\"JSXFragment\":[\"openingFragment\",\"children\",\"closingFragment\"],\"JSXOpeningFragment\":[],\"JSXClosingFragment\":[],\"Noop\":[],\"ParenthesizedExpression\":[\"expression\"],\"AwaitExpression\":[\"argument\"],\"BindExpression\":[\"object\",\"callee\"],\"ClassProperty\":[\"key\",\"value\",\"typeAnnotation\",\"decorators\"],\"OptionalMemberExpression\":[\"object\",\"property\"],\"OptionalCallExpression\":[\"callee\",\"arguments\",\"typeParameters\",\"typeArguments\"],\"ClassPrivateProperty\":[\"key\",\"value\"],\"Import\":[],\"Decorator\":[\"expression\"],\"DoExpression\":[\"body\"],\"ExportDefaultSpecifier\":[\"exported\"],\"ExportNamespaceSpecifier\":[\"exported\"],\"PrivateName\":[\"id\"],\"BigIntLiteral\":[],\"TSParameterProperty\":[\"parameter\"],\"TSDeclareFunction\":[\"id\",\"typeParameters\",\"params\",\"returnType\"],\"TSDeclareMethod\":[\"decorators\",\"key\",\"typeParameters\",\"params\",\"returnType\"],\"TSQualifiedName\":[\"left\",\"right\"],\"TSCallSignatureDeclaration\":[\"typeParameters\",\"parameters\",\"typeAnnotation\"],\"TSConstructSignatureDeclaration\":[\"typeParameters\",\"parameters\",\"typeAnnotation\"],\"TSPropertySignature\":[\"key\",\"typeAnnotation\",\"initializer\"],\"TSMethodSignature\":[\"key\",\"typeParameters\",\"parameters\",\"typeAnnotation\"],\"TSIndexSignature\":[\"parameters\",\"typeAnnotation\"],\"TSAnyKeyword\":[],\"TSUnknownKeyword\":[],\"TSNumberKeyword\":[],\"TSObjectKeyword\":[],\"TSBooleanKeyword\":[],\"TSStringKeyword\":[],\"TSSymbolKeyword\":[],\"TSVoidKeyword\":[],\"TSUndefinedKeyword\":[],\"TSNullKeyword\":[],\"TSNeverKeyword\":[],\"TSThisType\":[],\"TSFunctionType\":[\"typeParameters\",\"typeAnnotation\"],\"TSConstructorType\":[\"typeParameters\",\"typeAnnotation\"],\"TSTypeReference\":[\"typeName\",\"typeParameters\"],\"TSTypePredicate\":[\"parameterName\",\"typeAnnotation\"],\"TSTypeQuery\":[\"exprName\"],\"TSTypeLiteral\":[\"members\"],\"TSArrayType\":[\"elementType\"],\"TSTupleType\":[\"elementTypes\"],\"TSOptionalType\":[\"typeAnnotation\"],\"TSRestType\":[\"typeAnnotation\"],\"TSUnionType\":[\"types\"],\"TSIntersectionType\":[\"types\"],\"TSConditionalType\":[\"checkType\",\"extendsType\",\"trueType\",\"falseType\"],\"TSInferType\":[\"typeParameter\"],\"TSParenthesizedType\":[\"typeAnnotation\"],\"TSTypeOperator\":[\"typeAnnotation\"],\"TSIndexedAccessType\":[\"objectType\",\"indexType\"],\"TSMappedType\":[\"typeParameter\",\"typeAnnotation\"],\"TSLiteralType\":[\"literal\"],\"TSExpressionWithTypeArguments\":[\"expression\",\"typeParameters\"],\"TSInterfaceDeclaration\":[\"id\",\"typeParameters\",\"extends\",\"body\"],\"TSInterfaceBody\":[\"body\"],\"TSTypeAliasDeclaration\":[\"id\",\"typeParameters\",\"typeAnnotation\"],\"TSAsExpression\":[\"expression\",\"typeAnnotation\"],\"TSTypeAssertion\":[\"typeAnnotation\",\"expression\"],\"TSEnumDeclaration\":[\"id\",\"members\"],\"TSEnumMember\":[\"id\",\"initializer\"],\"TSModuleDeclaration\":[\"id\",\"body\"],\"TSModuleBlock\":[\"body\"],\"TSImportEqualsDeclaration\":[\"id\",\"moduleReference\"],\"TSExternalModuleReference\":[\"expression\"],\"TSNonNullExpression\":[\"expression\"],\"TSExportAssignment\":[\"expression\"],\"TSNamespaceExportDeclaration\":[\"id\"],\"TSTypeAnnotation\":[\"typeAnnotation\"],\"TSTypeParameterInstantiation\":[\"params\"],\"TSTypeParameterDeclaration\":[\"params\"],\"TSTypeParameter\":[\"constraint\",\"default\"]}",
    _powerAssertRecorder = function () { function PowerAssertRecorder() { this.captured = []; } PowerAssertRecorder.prototype._capt = function _capt(value, espath) { this.captured.push({ value: value, espath: espath }); return value; }; PowerAssertRecorder.prototype._expr = function _expr(value, source) { var capturedValues = this.captured; this.captured = []; return { powerAssertContext: { value: value, events: capturedValues }, source: source }; }; return PowerAssertRecorder; }();

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/** @test {ICOGenerator} */
describe('ICOGenerator', () => {
  const Module = (0, _rewire.default)('./ico-generator.js'); // Private constants

  const HEADER_SIZE = 6;
  const DIRECTORY_SIZE = 16;
  const BITMAPINFOHEADER_SIZE = 40;
  const BI_RGB = 0;
  /** @test {GenerateICO} */

  it('generate', () => {
    const targets = (0, _icoGenerator.GetRequiredICOImageSizes)().map(size => {
      const path = _path.default.join('./examples/data', size + '.png');

      return {
        size: size,
        path: path,
        stat: _fs.default.statSync(path)
      };
    });
    (0, _icoGenerator.default)(targets, './examples/data', {}, new _logger.default()).then(result => {
      var _rec = new _powerAssertRecorder();

      (0, _powerAssert.default)(_rec._expr(_rec._capt(result, "arguments/0"), {
        content: "assert(result)",
        filepath: "src/lib/ico-generator.test.js",
        line: 26,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"result\",\"range\":[7,13]}],\"range\":[0,14]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"result\",\"range\":[7,13]},{\"type\":{\"label\":\")\"},\"range\":[13,14]}]",
        visitorKeys: _powerAssertVisitorKeys
      }));

      _fs.default.unlinkSync(result);
    });
  });
  /** @test {createFileHeader} */

  it('createFileHeader', () => {
    var _rec2 = new _powerAssertRecorder(),
        _rec3 = new _powerAssertRecorder(),
        _rec4 = new _powerAssertRecorder();

    const createFileHeader = Module.__get__('createFileHeader');

    const count = 7;
    const b = createFileHeader(count);
    (0, _powerAssert.default)(_rec2._expr(_rec2._capt(_rec2._capt(_rec2._capt(b, "arguments/0/left/callee/object").readUInt16LE(0), "arguments/0/left") === 0, "arguments/0"), {
      content: "assert(b.readUInt16LE(0) === 0)",
      filepath: "src/lib/ico-generator.test.js",
      line: 37,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt16LE\",\"range\":[9,21]},\"computed\":false,\"range\":[7,21]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":0,\"range\":[22,23]}],\"range\":[7,24]},\"right\":{\"type\":\"NumericLiteral\",\"value\":0,\"range\":[29,30]},\"range\":[7,30]}],\"range\":[0,31]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt16LE\",\"range\":[9,21]},{\"type\":{\"label\":\"(\"},\"range\":[21,22]},{\"type\":{\"label\":\"num\"},\"value\":0,\"range\":[22,23]},{\"type\":{\"label\":\")\"},\"range\":[23,24]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[25,28]},{\"type\":{\"label\":\"num\"},\"value\":0,\"range\":[29,30]},{\"type\":{\"label\":\")\"},\"range\":[30,31]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec3._expr(_rec3._capt(_rec3._capt(_rec3._capt(b, "arguments/0/left/callee/object").readUInt16LE(2), "arguments/0/left") === 1, "arguments/0"), {
      content: "assert(b.readUInt16LE(2) === 1)",
      filepath: "src/lib/ico-generator.test.js",
      line: 38,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt16LE\",\"range\":[9,21]},\"computed\":false,\"range\":[7,21]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":2,\"range\":[22,23]}],\"range\":[7,24]},\"right\":{\"type\":\"NumericLiteral\",\"value\":1,\"range\":[29,30]},\"range\":[7,30]}],\"range\":[0,31]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt16LE\",\"range\":[9,21]},{\"type\":{\"label\":\"(\"},\"range\":[21,22]},{\"type\":{\"label\":\"num\"},\"value\":2,\"range\":[22,23]},{\"type\":{\"label\":\")\"},\"range\":[23,24]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[25,28]},{\"type\":{\"label\":\"num\"},\"value\":1,\"range\":[29,30]},{\"type\":{\"label\":\")\"},\"range\":[30,31]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec4._expr(_rec4._capt(_rec4._capt(_rec4._capt(b, "arguments/0/left/callee/object").readUInt16LE(4), "arguments/0/left") === _rec4._capt(count, "arguments/0/right"), "arguments/0"), {
      content: "assert(b.readUInt16LE(4) === count)",
      filepath: "src/lib/ico-generator.test.js",
      line: 39,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt16LE\",\"range\":[9,21]},\"computed\":false,\"range\":[7,21]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":4,\"range\":[22,23]}],\"range\":[7,24]},\"right\":{\"type\":\"Identifier\",\"name\":\"count\",\"range\":[29,34]},\"range\":[7,34]}],\"range\":[0,35]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt16LE\",\"range\":[9,21]},{\"type\":{\"label\":\"(\"},\"range\":[21,22]},{\"type\":{\"label\":\"num\"},\"value\":4,\"range\":[22,23]},{\"type\":{\"label\":\")\"},\"range\":[23,24]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[25,28]},{\"type\":{\"label\":\"name\"},\"value\":\"count\",\"range\":[29,34]},{\"type\":{\"label\":\")\"},\"range\":[34,35]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
  });
  /** @test {createDirectory} */

  it('createDirectory', () => {
    var _rec5 = new _powerAssertRecorder(),
        _rec6 = new _powerAssertRecorder(),
        _rec7 = new _powerAssertRecorder(),
        _rec8 = new _powerAssertRecorder(),
        _rec9 = new _powerAssertRecorder(),
        _rec10 = new _powerAssertRecorder(),
        _rec11 = new _powerAssertRecorder(),
        _rec12 = new _powerAssertRecorder();

    const createDirectory = Module.__get__('createDirectory');

    const png = {
      width: 16,
      height: 16,
      bpp: 4,
      data: {
        length: 1024
      }
    };
    const offset = HEADER_SIZE + DIRECTORY_SIZE;
    const b = createDirectory(png, offset);
    (0, _powerAssert.default)(_rec5._expr(_rec5._capt(_rec5._capt(_rec5._capt(b, "arguments/0/left/callee/object").readUInt8(0), "arguments/0/left") === _rec5._capt(_rec5._capt(png, "arguments/0/right/object").width, "arguments/0/right"), "arguments/0"), {
      content: "assert(b.readUInt8(0) === png.width)",
      filepath: "src/lib/ico-generator.test.js",
      line: 57,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt8\",\"range\":[9,18]},\"computed\":false,\"range\":[7,18]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":0,\"range\":[19,20]}],\"range\":[7,21]},\"right\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"png\",\"range\":[26,29]},\"property\":{\"type\":\"Identifier\",\"name\":\"width\",\"range\":[30,35]},\"computed\":false,\"range\":[26,35]},\"range\":[7,35]}],\"range\":[0,36]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt8\",\"range\":[9,18]},{\"type\":{\"label\":\"(\"},\"range\":[18,19]},{\"type\":{\"label\":\"num\"},\"value\":0,\"range\":[19,20]},{\"type\":{\"label\":\")\"},\"range\":[20,21]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[22,25]},{\"type\":{\"label\":\"name\"},\"value\":\"png\",\"range\":[26,29]},{\"type\":{\"label\":\".\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"width\",\"range\":[30,35]},{\"type\":{\"label\":\")\"},\"range\":[35,36]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec6._expr(_rec6._capt(_rec6._capt(_rec6._capt(b, "arguments/0/left/callee/object").readUInt8(1), "arguments/0/left") === _rec6._capt(_rec6._capt(png, "arguments/0/right/object").height, "arguments/0/right"), "arguments/0"), {
      content: "assert(b.readUInt8(1) === png.height)",
      filepath: "src/lib/ico-generator.test.js",
      line: 58,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt8\",\"range\":[9,18]},\"computed\":false,\"range\":[7,18]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":1,\"range\":[19,20]}],\"range\":[7,21]},\"right\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"png\",\"range\":[26,29]},\"property\":{\"type\":\"Identifier\",\"name\":\"height\",\"range\":[30,36]},\"computed\":false,\"range\":[26,36]},\"range\":[7,36]}],\"range\":[0,37]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt8\",\"range\":[9,18]},{\"type\":{\"label\":\"(\"},\"range\":[18,19]},{\"type\":{\"label\":\"num\"},\"value\":1,\"range\":[19,20]},{\"type\":{\"label\":\")\"},\"range\":[20,21]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[22,25]},{\"type\":{\"label\":\"name\"},\"value\":\"png\",\"range\":[26,29]},{\"type\":{\"label\":\".\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"height\",\"range\":[30,36]},{\"type\":{\"label\":\")\"},\"range\":[36,37]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec7._expr(_rec7._capt(_rec7._capt(_rec7._capt(b, "arguments/0/left/callee/object").readUInt8(2), "arguments/0/left") === 0, "arguments/0"), {
      content: "assert(b.readUInt8(2) === 0)",
      filepath: "src/lib/ico-generator.test.js",
      line: 59,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt8\",\"range\":[9,18]},\"computed\":false,\"range\":[7,18]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":2,\"range\":[19,20]}],\"range\":[7,21]},\"right\":{\"type\":\"NumericLiteral\",\"value\":0,\"range\":[26,27]},\"range\":[7,27]}],\"range\":[0,28]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt8\",\"range\":[9,18]},{\"type\":{\"label\":\"(\"},\"range\":[18,19]},{\"type\":{\"label\":\"num\"},\"value\":2,\"range\":[19,20]},{\"type\":{\"label\":\")\"},\"range\":[20,21]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[22,25]},{\"type\":{\"label\":\"num\"},\"value\":0,\"range\":[26,27]},{\"type\":{\"label\":\")\"},\"range\":[27,28]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec8._expr(_rec8._capt(_rec8._capt(_rec8._capt(b, "arguments/0/left/callee/object").readUInt8(3), "arguments/0/left") === 0, "arguments/0"), {
      content: "assert(b.readUInt8(3) === 0)",
      filepath: "src/lib/ico-generator.test.js",
      line: 60,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt8\",\"range\":[9,18]},\"computed\":false,\"range\":[7,18]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":3,\"range\":[19,20]}],\"range\":[7,21]},\"right\":{\"type\":\"NumericLiteral\",\"value\":0,\"range\":[26,27]},\"range\":[7,27]}],\"range\":[0,28]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt8\",\"range\":[9,18]},{\"type\":{\"label\":\"(\"},\"range\":[18,19]},{\"type\":{\"label\":\"num\"},\"value\":3,\"range\":[19,20]},{\"type\":{\"label\":\")\"},\"range\":[20,21]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[22,25]},{\"type\":{\"label\":\"num\"},\"value\":0,\"range\":[26,27]},{\"type\":{\"label\":\")\"},\"range\":[27,28]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec9._expr(_rec9._capt(_rec9._capt(_rec9._capt(b, "arguments/0/left/callee/object").readUInt16LE(4), "arguments/0/left") === 1, "arguments/0"), {
      content: "assert(b.readUInt16LE(4) === 1)",
      filepath: "src/lib/ico-generator.test.js",
      line: 61,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt16LE\",\"range\":[9,21]},\"computed\":false,\"range\":[7,21]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":4,\"range\":[22,23]}],\"range\":[7,24]},\"right\":{\"type\":\"NumericLiteral\",\"value\":1,\"range\":[29,30]},\"range\":[7,30]}],\"range\":[0,31]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt16LE\",\"range\":[9,21]},{\"type\":{\"label\":\"(\"},\"range\":[21,22]},{\"type\":{\"label\":\"num\"},\"value\":4,\"range\":[22,23]},{\"type\":{\"label\":\")\"},\"range\":[23,24]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[25,28]},{\"type\":{\"label\":\"num\"},\"value\":1,\"range\":[29,30]},{\"type\":{\"label\":\")\"},\"range\":[30,31]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec10._expr(_rec10._capt(_rec10._capt(_rec10._capt(b, "arguments/0/left/callee/object").readUInt16LE(6), "arguments/0/left") === _rec10._capt(_rec10._capt(_rec10._capt(png, "arguments/0/right/left/object").bpp, "arguments/0/right/left") * 8, "arguments/0/right"), "arguments/0"), {
      content: "assert(b.readUInt16LE(6) === png.bpp * 8)",
      filepath: "src/lib/ico-generator.test.js",
      line: 62,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt16LE\",\"range\":[9,21]},\"computed\":false,\"range\":[7,21]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":6,\"range\":[22,23]}],\"range\":[7,24]},\"right\":{\"type\":\"BinaryExpression\",\"operator\":\"*\",\"left\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"png\",\"range\":[29,32]},\"property\":{\"type\":\"Identifier\",\"name\":\"bpp\",\"range\":[33,36]},\"computed\":false,\"range\":[29,36]},\"right\":{\"type\":\"NumericLiteral\",\"value\":8,\"range\":[39,40]},\"range\":[29,40]},\"range\":[7,40]}],\"range\":[0,41]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt16LE\",\"range\":[9,21]},{\"type\":{\"label\":\"(\"},\"range\":[21,22]},{\"type\":{\"label\":\"num\"},\"value\":6,\"range\":[22,23]},{\"type\":{\"label\":\")\"},\"range\":[23,24]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[25,28]},{\"type\":{\"label\":\"name\"},\"value\":\"png\",\"range\":[29,32]},{\"type\":{\"label\":\".\"},\"range\":[32,33]},{\"type\":{\"label\":\"name\"},\"value\":\"bpp\",\"range\":[33,36]},{\"type\":{\"label\":\"*\"},\"value\":\"*\",\"range\":[37,38]},{\"type\":{\"label\":\"num\"},\"value\":8,\"range\":[39,40]},{\"type\":{\"label\":\")\"},\"range\":[40,41]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec11._expr(_rec11._capt(_rec11._capt(_rec11._capt(b, "arguments/0/left/callee/object").readUInt32LE(8), "arguments/0/left") === _rec11._capt(_rec11._capt(_rec11._capt(_rec11._capt(png, "arguments/0/right/left/object/object").data, "arguments/0/right/left/object").length, "arguments/0/right/left") + _rec11._capt(BITMAPINFOHEADER_SIZE, "arguments/0/right/right"), "arguments/0/right"), "arguments/0"), {
      content: "assert(b.readUInt32LE(8) === png.data.length + BITMAPINFOHEADER_SIZE)",
      filepath: "src/lib/ico-generator.test.js",
      line: 63,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt32LE\",\"range\":[9,21]},\"computed\":false,\"range\":[7,21]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":8,\"range\":[22,23]}],\"range\":[7,24]},\"right\":{\"type\":\"BinaryExpression\",\"operator\":\"+\",\"left\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"png\",\"range\":[29,32]},\"property\":{\"type\":\"Identifier\",\"name\":\"data\",\"range\":[33,37]},\"computed\":false,\"range\":[29,37]},\"property\":{\"type\":\"Identifier\",\"name\":\"length\",\"range\":[38,44]},\"computed\":false,\"range\":[29,44]},\"right\":{\"type\":\"Identifier\",\"name\":\"BITMAPINFOHEADER_SIZE\",\"range\":[47,68]},\"range\":[29,68]},\"range\":[7,68]}],\"range\":[0,69]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt32LE\",\"range\":[9,21]},{\"type\":{\"label\":\"(\"},\"range\":[21,22]},{\"type\":{\"label\":\"num\"},\"value\":8,\"range\":[22,23]},{\"type\":{\"label\":\")\"},\"range\":[23,24]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[25,28]},{\"type\":{\"label\":\"name\"},\"value\":\"png\",\"range\":[29,32]},{\"type\":{\"label\":\".\"},\"range\":[32,33]},{\"type\":{\"label\":\"name\"},\"value\":\"data\",\"range\":[33,37]},{\"type\":{\"label\":\".\"},\"range\":[37,38]},{\"type\":{\"label\":\"name\"},\"value\":\"length\",\"range\":[38,44]},{\"type\":{\"label\":\"+/-\"},\"value\":\"+\",\"range\":[45,46]},{\"type\":{\"label\":\"name\"},\"value\":\"BITMAPINFOHEADER_SIZE\",\"range\":[47,68]},{\"type\":{\"label\":\")\"},\"range\":[68,69]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec12._expr(_rec12._capt(_rec12._capt(_rec12._capt(b, "arguments/0/left/callee/object").readUInt32LE(12), "arguments/0/left") === _rec12._capt(offset, "arguments/0/right"), "arguments/0"), {
      content: "assert(b.readUInt32LE(12) === offset)",
      filepath: "src/lib/ico-generator.test.js",
      line: 64,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt32LE\",\"range\":[9,21]},\"computed\":false,\"range\":[7,21]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":12,\"range\":[22,24]}],\"range\":[7,25]},\"right\":{\"type\":\"Identifier\",\"name\":\"offset\",\"range\":[30,36]},\"range\":[7,36]}],\"range\":[0,37]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt32LE\",\"range\":[9,21]},{\"type\":{\"label\":\"(\"},\"range\":[21,22]},{\"type\":{\"label\":\"num\"},\"value\":12,\"range\":[22,24]},{\"type\":{\"label\":\")\"},\"range\":[24,25]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[26,29]},{\"type\":{\"label\":\"name\"},\"value\":\"offset\",\"range\":[30,36]},{\"type\":{\"label\":\")\"},\"range\":[36,37]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
  });
  /** @test {createBitmapInfoHeader} */

  it('createBitmapInfoHeader', () => {
    var _rec13 = new _powerAssertRecorder(),
        _rec14 = new _powerAssertRecorder(),
        _rec15 = new _powerAssertRecorder(),
        _rec16 = new _powerAssertRecorder(),
        _rec17 = new _powerAssertRecorder(),
        _rec18 = new _powerAssertRecorder(),
        _rec19 = new _powerAssertRecorder(),
        _rec20 = new _powerAssertRecorder(),
        _rec21 = new _powerAssertRecorder(),
        _rec22 = new _powerAssertRecorder(),
        _rec23 = new _powerAssertRecorder();

    const createBitmapInfoHeader = Module.__get__('createBitmapInfoHeader');

    const png = {
      width: 16,
      height: 16,
      bpp: 4,
      data: {
        length: 1024
      }
    };
    const b = createBitmapInfoHeader(png, BI_RGB);
    (0, _powerAssert.default)(_rec13._expr(_rec13._capt(_rec13._capt(_rec13._capt(b, "arguments/0/left/callee/object").readUInt32LE(0), "arguments/0/left") === _rec13._capt(BITMAPINFOHEADER_SIZE, "arguments/0/right"), "arguments/0"), {
      content: "assert(b.readUInt32LE(0) === BITMAPINFOHEADER_SIZE)",
      filepath: "src/lib/ico-generator.test.js",
      line: 80,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt32LE\",\"range\":[9,21]},\"computed\":false,\"range\":[7,21]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":0,\"range\":[22,23]}],\"range\":[7,24]},\"right\":{\"type\":\"Identifier\",\"name\":\"BITMAPINFOHEADER_SIZE\",\"range\":[29,50]},\"range\":[7,50]}],\"range\":[0,51]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt32LE\",\"range\":[9,21]},{\"type\":{\"label\":\"(\"},\"range\":[21,22]},{\"type\":{\"label\":\"num\"},\"value\":0,\"range\":[22,23]},{\"type\":{\"label\":\")\"},\"range\":[23,24]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[25,28]},{\"type\":{\"label\":\"name\"},\"value\":\"BITMAPINFOHEADER_SIZE\",\"range\":[29,50]},{\"type\":{\"label\":\")\"},\"range\":[50,51]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec14._expr(_rec14._capt(_rec14._capt(_rec14._capt(b, "arguments/0/left/callee/object").readInt32LE(4), "arguments/0/left") === _rec14._capt(_rec14._capt(png, "arguments/0/right/object").width, "arguments/0/right"), "arguments/0"), {
      content: "assert(b.readInt32LE(4) === png.width)",
      filepath: "src/lib/ico-generator.test.js",
      line: 81,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readInt32LE\",\"range\":[9,20]},\"computed\":false,\"range\":[7,20]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":4,\"range\":[21,22]}],\"range\":[7,23]},\"right\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"png\",\"range\":[28,31]},\"property\":{\"type\":\"Identifier\",\"name\":\"width\",\"range\":[32,37]},\"computed\":false,\"range\":[28,37]},\"range\":[7,37]}],\"range\":[0,38]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readInt32LE\",\"range\":[9,20]},{\"type\":{\"label\":\"(\"},\"range\":[20,21]},{\"type\":{\"label\":\"num\"},\"value\":4,\"range\":[21,22]},{\"type\":{\"label\":\")\"},\"range\":[22,23]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[24,27]},{\"type\":{\"label\":\"name\"},\"value\":\"png\",\"range\":[28,31]},{\"type\":{\"label\":\".\"},\"range\":[31,32]},{\"type\":{\"label\":\"name\"},\"value\":\"width\",\"range\":[32,37]},{\"type\":{\"label\":\")\"},\"range\":[37,38]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec15._expr(_rec15._capt(_rec15._capt(_rec15._capt(b, "arguments/0/left/callee/object").readInt32LE(8), "arguments/0/left") === _rec15._capt(_rec15._capt(_rec15._capt(png, "arguments/0/right/left/object").height, "arguments/0/right/left") * 2, "arguments/0/right"), "arguments/0"), {
      content: "assert(b.readInt32LE(8) === png.height * 2)",
      filepath: "src/lib/ico-generator.test.js",
      line: 82,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readInt32LE\",\"range\":[9,20]},\"computed\":false,\"range\":[7,20]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":8,\"range\":[21,22]}],\"range\":[7,23]},\"right\":{\"type\":\"BinaryExpression\",\"operator\":\"*\",\"left\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"png\",\"range\":[28,31]},\"property\":{\"type\":\"Identifier\",\"name\":\"height\",\"range\":[32,38]},\"computed\":false,\"range\":[28,38]},\"right\":{\"type\":\"NumericLiteral\",\"value\":2,\"range\":[41,42]},\"range\":[28,42]},\"range\":[7,42]}],\"range\":[0,43]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readInt32LE\",\"range\":[9,20]},{\"type\":{\"label\":\"(\"},\"range\":[20,21]},{\"type\":{\"label\":\"num\"},\"value\":8,\"range\":[21,22]},{\"type\":{\"label\":\")\"},\"range\":[22,23]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[24,27]},{\"type\":{\"label\":\"name\"},\"value\":\"png\",\"range\":[28,31]},{\"type\":{\"label\":\".\"},\"range\":[31,32]},{\"type\":{\"label\":\"name\"},\"value\":\"height\",\"range\":[32,38]},{\"type\":{\"label\":\"*\"},\"value\":\"*\",\"range\":[39,40]},{\"type\":{\"label\":\"num\"},\"value\":2,\"range\":[41,42]},{\"type\":{\"label\":\")\"},\"range\":[42,43]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec16._expr(_rec16._capt(_rec16._capt(_rec16._capt(b, "arguments/0/left/callee/object").readUInt16LE(12), "arguments/0/left") === 1, "arguments/0"), {
      content: "assert(b.readUInt16LE(12) === 1)",
      filepath: "src/lib/ico-generator.test.js",
      line: 83,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt16LE\",\"range\":[9,21]},\"computed\":false,\"range\":[7,21]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":12,\"range\":[22,24]}],\"range\":[7,25]},\"right\":{\"type\":\"NumericLiteral\",\"value\":1,\"range\":[30,31]},\"range\":[7,31]}],\"range\":[0,32]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt16LE\",\"range\":[9,21]},{\"type\":{\"label\":\"(\"},\"range\":[21,22]},{\"type\":{\"label\":\"num\"},\"value\":12,\"range\":[22,24]},{\"type\":{\"label\":\")\"},\"range\":[24,25]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[26,29]},{\"type\":{\"label\":\"num\"},\"value\":1,\"range\":[30,31]},{\"type\":{\"label\":\")\"},\"range\":[31,32]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec17._expr(_rec17._capt(_rec17._capt(_rec17._capt(b, "arguments/0/left/callee/object").readUInt16LE(14), "arguments/0/left") === _rec17._capt(_rec17._capt(_rec17._capt(png, "arguments/0/right/left/object").bpp, "arguments/0/right/left") * 8, "arguments/0/right"), "arguments/0"), {
      content: "assert(b.readUInt16LE(14) === png.bpp * 8)",
      filepath: "src/lib/ico-generator.test.js",
      line: 84,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt16LE\",\"range\":[9,21]},\"computed\":false,\"range\":[7,21]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":14,\"range\":[22,24]}],\"range\":[7,25]},\"right\":{\"type\":\"BinaryExpression\",\"operator\":\"*\",\"left\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"png\",\"range\":[30,33]},\"property\":{\"type\":\"Identifier\",\"name\":\"bpp\",\"range\":[34,37]},\"computed\":false,\"range\":[30,37]},\"right\":{\"type\":\"NumericLiteral\",\"value\":8,\"range\":[40,41]},\"range\":[30,41]},\"range\":[7,41]}],\"range\":[0,42]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt16LE\",\"range\":[9,21]},{\"type\":{\"label\":\"(\"},\"range\":[21,22]},{\"type\":{\"label\":\"num\"},\"value\":14,\"range\":[22,24]},{\"type\":{\"label\":\")\"},\"range\":[24,25]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[26,29]},{\"type\":{\"label\":\"name\"},\"value\":\"png\",\"range\":[30,33]},{\"type\":{\"label\":\".\"},\"range\":[33,34]},{\"type\":{\"label\":\"name\"},\"value\":\"bpp\",\"range\":[34,37]},{\"type\":{\"label\":\"*\"},\"value\":\"*\",\"range\":[38,39]},{\"type\":{\"label\":\"num\"},\"value\":8,\"range\":[40,41]},{\"type\":{\"label\":\")\"},\"range\":[41,42]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec18._expr(_rec18._capt(_rec18._capt(_rec18._capt(b, "arguments/0/left/callee/object").readUInt32LE(16), "arguments/0/left") === _rec18._capt(BI_RGB, "arguments/0/right"), "arguments/0"), {
      content: "assert(b.readUInt32LE(16) === BI_RGB)",
      filepath: "src/lib/ico-generator.test.js",
      line: 85,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt32LE\",\"range\":[9,21]},\"computed\":false,\"range\":[7,21]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":16,\"range\":[22,24]}],\"range\":[7,25]},\"right\":{\"type\":\"Identifier\",\"name\":\"BI_RGB\",\"range\":[30,36]},\"range\":[7,36]}],\"range\":[0,37]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt32LE\",\"range\":[9,21]},{\"type\":{\"label\":\"(\"},\"range\":[21,22]},{\"type\":{\"label\":\"num\"},\"value\":16,\"range\":[22,24]},{\"type\":{\"label\":\")\"},\"range\":[24,25]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[26,29]},{\"type\":{\"label\":\"name\"},\"value\":\"BI_RGB\",\"range\":[30,36]},{\"type\":{\"label\":\")\"},\"range\":[36,37]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec19._expr(_rec19._capt(_rec19._capt(_rec19._capt(b, "arguments/0/left/callee/object").readUInt32LE(20), "arguments/0/left") === _rec19._capt(_rec19._capt(_rec19._capt(png, "arguments/0/right/object/object").data, "arguments/0/right/object").length, "arguments/0/right"), "arguments/0"), {
      content: "assert(b.readUInt32LE(20) === png.data.length)",
      filepath: "src/lib/ico-generator.test.js",
      line: 86,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt32LE\",\"range\":[9,21]},\"computed\":false,\"range\":[7,21]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":20,\"range\":[22,24]}],\"range\":[7,25]},\"right\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"png\",\"range\":[30,33]},\"property\":{\"type\":\"Identifier\",\"name\":\"data\",\"range\":[34,38]},\"computed\":false,\"range\":[30,38]},\"property\":{\"type\":\"Identifier\",\"name\":\"length\",\"range\":[39,45]},\"computed\":false,\"range\":[30,45]},\"range\":[7,45]}],\"range\":[0,46]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt32LE\",\"range\":[9,21]},{\"type\":{\"label\":\"(\"},\"range\":[21,22]},{\"type\":{\"label\":\"num\"},\"value\":20,\"range\":[22,24]},{\"type\":{\"label\":\")\"},\"range\":[24,25]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[26,29]},{\"type\":{\"label\":\"name\"},\"value\":\"png\",\"range\":[30,33]},{\"type\":{\"label\":\".\"},\"range\":[33,34]},{\"type\":{\"label\":\"name\"},\"value\":\"data\",\"range\":[34,38]},{\"type\":{\"label\":\".\"},\"range\":[38,39]},{\"type\":{\"label\":\"name\"},\"value\":\"length\",\"range\":[39,45]},{\"type\":{\"label\":\")\"},\"range\":[45,46]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec20._expr(_rec20._capt(_rec20._capt(_rec20._capt(b, "arguments/0/left/callee/object").readInt32LE(24), "arguments/0/left") === 0, "arguments/0"), {
      content: "assert(b.readInt32LE(24) === 0)",
      filepath: "src/lib/ico-generator.test.js",
      line: 87,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readInt32LE\",\"range\":[9,20]},\"computed\":false,\"range\":[7,20]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":24,\"range\":[21,23]}],\"range\":[7,24]},\"right\":{\"type\":\"NumericLiteral\",\"value\":0,\"range\":[29,30]},\"range\":[7,30]}],\"range\":[0,31]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readInt32LE\",\"range\":[9,20]},{\"type\":{\"label\":\"(\"},\"range\":[20,21]},{\"type\":{\"label\":\"num\"},\"value\":24,\"range\":[21,23]},{\"type\":{\"label\":\")\"},\"range\":[23,24]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[25,28]},{\"type\":{\"label\":\"num\"},\"value\":0,\"range\":[29,30]},{\"type\":{\"label\":\")\"},\"range\":[30,31]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec21._expr(_rec21._capt(_rec21._capt(_rec21._capt(b, "arguments/0/left/callee/object").readInt32LE(28), "arguments/0/left") === 0, "arguments/0"), {
      content: "assert(b.readInt32LE(28) === 0)",
      filepath: "src/lib/ico-generator.test.js",
      line: 88,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readInt32LE\",\"range\":[9,20]},\"computed\":false,\"range\":[7,20]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":28,\"range\":[21,23]}],\"range\":[7,24]},\"right\":{\"type\":\"NumericLiteral\",\"value\":0,\"range\":[29,30]},\"range\":[7,30]}],\"range\":[0,31]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readInt32LE\",\"range\":[9,20]},{\"type\":{\"label\":\"(\"},\"range\":[20,21]},{\"type\":{\"label\":\"num\"},\"value\":28,\"range\":[21,23]},{\"type\":{\"label\":\")\"},\"range\":[23,24]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[25,28]},{\"type\":{\"label\":\"num\"},\"value\":0,\"range\":[29,30]},{\"type\":{\"label\":\")\"},\"range\":[30,31]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec22._expr(_rec22._capt(_rec22._capt(_rec22._capt(b, "arguments/0/left/callee/object").readUInt32LE(32), "arguments/0/left") === 0, "arguments/0"), {
      content: "assert(b.readUInt32LE(32) === 0)",
      filepath: "src/lib/ico-generator.test.js",
      line: 89,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt32LE\",\"range\":[9,21]},\"computed\":false,\"range\":[7,21]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":32,\"range\":[22,24]}],\"range\":[7,25]},\"right\":{\"type\":\"NumericLiteral\",\"value\":0,\"range\":[30,31]},\"range\":[7,31]}],\"range\":[0,32]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt32LE\",\"range\":[9,21]},{\"type\":{\"label\":\"(\"},\"range\":[21,22]},{\"type\":{\"label\":\"num\"},\"value\":32,\"range\":[22,24]},{\"type\":{\"label\":\")\"},\"range\":[24,25]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[26,29]},{\"type\":{\"label\":\"num\"},\"value\":0,\"range\":[30,31]},{\"type\":{\"label\":\")\"},\"range\":[31,32]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    (0, _powerAssert.default)(_rec23._expr(_rec23._capt(_rec23._capt(_rec23._capt(b, "arguments/0/left/callee/object").readUInt32LE(36), "arguments/0/left") === 0, "arguments/0"), {
      content: "assert(b.readUInt32LE(36) === 0)",
      filepath: "src/lib/ico-generator.test.js",
      line: 90,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"b\",\"range\":[7,8]},\"property\":{\"type\":\"Identifier\",\"name\":\"readUInt32LE\",\"range\":[9,21]},\"computed\":false,\"range\":[7,21]},\"arguments\":[{\"type\":\"NumericLiteral\",\"value\":36,\"range\":[22,24]}],\"range\":[7,25]},\"right\":{\"type\":\"NumericLiteral\",\"value\":0,\"range\":[30,31]},\"range\":[7,31]}],\"range\":[0,32]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"b\",\"range\":[7,8]},{\"type\":{\"label\":\".\"},\"range\":[8,9]},{\"type\":{\"label\":\"name\"},\"value\":\"readUInt32LE\",\"range\":[9,21]},{\"type\":{\"label\":\"(\"},\"range\":[21,22]},{\"type\":{\"label\":\"num\"},\"value\":36,\"range\":[22,24]},{\"type\":{\"label\":\")\"},\"range\":[24,25]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[26,29]},{\"type\":{\"label\":\"num\"},\"value\":0,\"range\":[30,31]},{\"type\":{\"label\":\")\"},\"range\":[31,32]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
  });
});