"use strict";

var _powerAssert = _interopRequireDefault(require("power-assert"));

var _fs = _interopRequireDefault(require("fs"));

var _del = _interopRequireDefault(require("del"));

var _logger = _interopRequireDefault(require("./logger.js"));

var _pngGenerator = require("./png-generator.js");

var _faviconGenerator = require("./favicon-generator.js");

var _icnsGenerator = require("./icns-generator.js");

var _icoGenerator = require("./ico-generator.js");

var _util = _interopRequireDefault(require("./util.js"));

var _rewire = _interopRequireDefault(require("rewire"));

var _powerAssertVisitorKeys = "{\"ArrayExpression\":[\"elements\"],\"AssignmentExpression\":[\"left\",\"right\"],\"BinaryExpression\":[\"left\",\"right\"],\"InterpreterDirective\":[],\"Directive\":[\"value\"],\"DirectiveLiteral\":[],\"BlockStatement\":[\"directives\",\"body\"],\"BreakStatement\":[\"label\"],\"CallExpression\":[\"callee\",\"arguments\",\"typeParameters\",\"typeArguments\"],\"CatchClause\":[\"param\",\"body\"],\"ConditionalExpression\":[\"test\",\"consequent\",\"alternate\"],\"ContinueStatement\":[\"label\"],\"DebuggerStatement\":[],\"DoWhileStatement\":[\"test\",\"body\"],\"EmptyStatement\":[],\"ExpressionStatement\":[\"expression\"],\"File\":[\"program\"],\"ForInStatement\":[\"left\",\"right\",\"body\"],\"ForStatement\":[\"init\",\"test\",\"update\",\"body\"],\"FunctionDeclaration\":[\"id\",\"params\",\"body\",\"returnType\",\"typeParameters\"],\"FunctionExpression\":[\"id\",\"params\",\"body\",\"returnType\",\"typeParameters\"],\"Identifier\":[\"typeAnnotation\"],\"IfStatement\":[\"test\",\"consequent\",\"alternate\"],\"LabeledStatement\":[\"label\",\"body\"],\"StringLiteral\":[],\"NumericLiteral\":[],\"NullLiteral\":[],\"BooleanLiteral\":[],\"RegExpLiteral\":[],\"LogicalExpression\":[\"left\",\"right\"],\"MemberExpression\":[\"object\",\"property\"],\"NewExpression\":[\"callee\",\"arguments\",\"typeParameters\",\"typeArguments\"],\"Program\":[\"directives\",\"body\"],\"ObjectExpression\":[\"properties\"],\"ObjectMethod\":[\"key\",\"params\",\"body\",\"decorators\",\"returnType\",\"typeParameters\"],\"ObjectProperty\":[\"key\",\"value\",\"decorators\"],\"RestElement\":[\"argument\",\"typeAnnotation\"],\"ReturnStatement\":[\"argument\"],\"SequenceExpression\":[\"expressions\"],\"SwitchCase\":[\"test\",\"consequent\"],\"SwitchStatement\":[\"discriminant\",\"cases\"],\"ThisExpression\":[],\"ThrowStatement\":[\"argument\"],\"TryStatement\":[\"block\",\"handler\",\"finalizer\"],\"UnaryExpression\":[\"argument\"],\"UpdateExpression\":[\"argument\"],\"VariableDeclaration\":[\"declarations\"],\"VariableDeclarator\":[\"id\",\"init\"],\"WhileStatement\":[\"test\",\"body\"],\"WithStatement\":[\"object\",\"body\"],\"AssignmentPattern\":[\"left\",\"right\"],\"ArrayPattern\":[\"elements\",\"typeAnnotation\"],\"ArrowFunctionExpression\":[\"params\",\"body\",\"returnType\",\"typeParameters\"],\"ClassBody\":[\"body\"],\"ClassDeclaration\":[\"id\",\"body\",\"superClass\",\"mixins\",\"typeParameters\",\"superTypeParameters\",\"implements\",\"decorators\"],\"ClassExpression\":[\"id\",\"body\",\"superClass\",\"mixins\",\"typeParameters\",\"superTypeParameters\",\"implements\",\"decorators\"],\"ExportAllDeclaration\":[\"source\"],\"ExportDefaultDeclaration\":[\"declaration\"],\"ExportNamedDeclaration\":[\"declaration\",\"specifiers\",\"source\"],\"ExportSpecifier\":[\"local\",\"exported\"],\"ForOfStatement\":[\"left\",\"right\",\"body\"],\"ImportDeclaration\":[\"specifiers\",\"source\"],\"ImportDefaultSpecifier\":[\"local\"],\"ImportNamespaceSpecifier\":[\"local\"],\"ImportSpecifier\":[\"local\",\"imported\"],\"MetaProperty\":[\"meta\",\"property\"],\"ClassMethod\":[\"key\",\"params\",\"body\",\"decorators\",\"returnType\",\"typeParameters\"],\"ObjectPattern\":[\"properties\",\"typeAnnotation\"],\"SpreadElement\":[\"argument\"],\"Super\":[],\"TaggedTemplateExpression\":[\"tag\",\"quasi\"],\"TemplateElement\":[],\"TemplateLiteral\":[\"quasis\",\"expressions\"],\"YieldExpression\":[\"argument\"],\"AnyTypeAnnotation\":[],\"ArrayTypeAnnotation\":[\"elementType\"],\"BooleanTypeAnnotation\":[],\"BooleanLiteralTypeAnnotation\":[],\"NullLiteralTypeAnnotation\":[],\"ClassImplements\":[\"id\",\"typeParameters\"],\"DeclareClass\":[\"id\",\"typeParameters\",\"extends\",\"mixins\",\"implements\",\"body\"],\"DeclareFunction\":[\"id\"],\"DeclareInterface\":[\"id\",\"typeParameters\",\"extends\",\"mixins\",\"implements\",\"body\"],\"DeclareModule\":[\"id\",\"body\"],\"DeclareModuleExports\":[\"typeAnnotation\"],\"DeclareTypeAlias\":[\"id\",\"typeParameters\",\"right\"],\"DeclareOpaqueType\":[\"id\",\"typeParameters\",\"supertype\"],\"DeclareVariable\":[\"id\"],\"DeclareExportDeclaration\":[\"declaration\",\"specifiers\",\"source\"],\"DeclareExportAllDeclaration\":[\"source\"],\"DeclaredPredicate\":[\"value\"],\"ExistsTypeAnnotation\":[],\"FunctionTypeAnnotation\":[\"typeParameters\",\"params\",\"rest\",\"returnType\"],\"FunctionTypeParam\":[\"name\",\"typeAnnotation\"],\"GenericTypeAnnotation\":[\"id\",\"typeParameters\"],\"InferredPredicate\":[],\"InterfaceExtends\":[\"id\",\"typeParameters\"],\"InterfaceDeclaration\":[\"id\",\"typeParameters\",\"extends\",\"mixins\",\"implements\",\"body\"],\"InterfaceTypeAnnotation\":[\"extends\",\"body\"],\"IntersectionTypeAnnotation\":[\"types\"],\"MixedTypeAnnotation\":[],\"EmptyTypeAnnotation\":[],\"NullableTypeAnnotation\":[\"typeAnnotation\"],\"NumberLiteralTypeAnnotation\":[],\"NumberTypeAnnotation\":[],\"ObjectTypeAnnotation\":[\"properties\",\"indexers\",\"callProperties\",\"internalSlots\"],\"ObjectTypeInternalSlot\":[\"id\",\"value\",\"optional\",\"static\",\"method\"],\"ObjectTypeCallProperty\":[\"value\"],\"ObjectTypeIndexer\":[\"id\",\"key\",\"value\",\"variance\"],\"ObjectTypeProperty\":[\"key\",\"value\",\"variance\"],\"ObjectTypeSpreadProperty\":[\"argument\"],\"OpaqueType\":[\"id\",\"typeParameters\",\"supertype\",\"impltype\"],\"QualifiedTypeIdentifier\":[\"id\",\"qualification\"],\"StringLiteralTypeAnnotation\":[],\"StringTypeAnnotation\":[],\"ThisTypeAnnotation\":[],\"TupleTypeAnnotation\":[\"types\"],\"TypeofTypeAnnotation\":[\"argument\"],\"TypeAlias\":[\"id\",\"typeParameters\",\"right\"],\"TypeAnnotation\":[\"typeAnnotation\"],\"TypeCastExpression\":[\"expression\",\"typeAnnotation\"],\"TypeParameter\":[\"bound\",\"default\",\"variance\"],\"TypeParameterDeclaration\":[\"params\"],\"TypeParameterInstantiation\":[\"params\"],\"UnionTypeAnnotation\":[\"types\"],\"Variance\":[],\"VoidTypeAnnotation\":[],\"JSXAttribute\":[\"name\",\"value\"],\"JSXClosingElement\":[\"name\"],\"JSXElement\":[\"openingElement\",\"children\",\"closingElement\"],\"JSXEmptyExpression\":[],\"JSXExpressionContainer\":[\"expression\"],\"JSXSpreadChild\":[\"expression\"],\"JSXIdentifier\":[],\"JSXMemberExpression\":[\"object\",\"property\"],\"JSXNamespacedName\":[\"namespace\",\"name\"],\"JSXOpeningElement\":[\"name\",\"attributes\"],\"JSXSpreadAttribute\":[\"argument\"],\"JSXText\":[],\"JSXFragment\":[\"openingFragment\",\"children\",\"closingFragment\"],\"JSXOpeningFragment\":[],\"JSXClosingFragment\":[],\"Noop\":[],\"ParenthesizedExpression\":[\"expression\"],\"AwaitExpression\":[\"argument\"],\"BindExpression\":[\"object\",\"callee\"],\"ClassProperty\":[\"key\",\"value\",\"typeAnnotation\",\"decorators\"],\"OptionalMemberExpression\":[\"object\",\"property\"],\"OptionalCallExpression\":[\"callee\",\"arguments\",\"typeParameters\",\"typeArguments\"],\"ClassPrivateProperty\":[\"key\",\"value\"],\"Import\":[],\"Decorator\":[\"expression\"],\"DoExpression\":[\"body\"],\"ExportDefaultSpecifier\":[\"exported\"],\"ExportNamespaceSpecifier\":[\"exported\"],\"PrivateName\":[\"id\"],\"BigIntLiteral\":[],\"TSParameterProperty\":[\"parameter\"],\"TSDeclareFunction\":[\"id\",\"typeParameters\",\"params\",\"returnType\"],\"TSDeclareMethod\":[\"decorators\",\"key\",\"typeParameters\",\"params\",\"returnType\"],\"TSQualifiedName\":[\"left\",\"right\"],\"TSCallSignatureDeclaration\":[\"typeParameters\",\"parameters\",\"typeAnnotation\"],\"TSConstructSignatureDeclaration\":[\"typeParameters\",\"parameters\",\"typeAnnotation\"],\"TSPropertySignature\":[\"key\",\"typeAnnotation\",\"initializer\"],\"TSMethodSignature\":[\"key\",\"typeParameters\",\"parameters\",\"typeAnnotation\"],\"TSIndexSignature\":[\"parameters\",\"typeAnnotation\"],\"TSAnyKeyword\":[],\"TSUnknownKeyword\":[],\"TSNumberKeyword\":[],\"TSObjectKeyword\":[],\"TSBooleanKeyword\":[],\"TSStringKeyword\":[],\"TSSymbolKeyword\":[],\"TSVoidKeyword\":[],\"TSUndefinedKeyword\":[],\"TSNullKeyword\":[],\"TSNeverKeyword\":[],\"TSThisType\":[],\"TSFunctionType\":[\"typeParameters\",\"typeAnnotation\"],\"TSConstructorType\":[\"typeParameters\",\"typeAnnotation\"],\"TSTypeReference\":[\"typeName\",\"typeParameters\"],\"TSTypePredicate\":[\"parameterName\",\"typeAnnotation\"],\"TSTypeQuery\":[\"exprName\"],\"TSTypeLiteral\":[\"members\"],\"TSArrayType\":[\"elementType\"],\"TSTupleType\":[\"elementTypes\"],\"TSOptionalType\":[\"typeAnnotation\"],\"TSRestType\":[\"typeAnnotation\"],\"TSUnionType\":[\"types\"],\"TSIntersectionType\":[\"types\"],\"TSConditionalType\":[\"checkType\",\"extendsType\",\"trueType\",\"falseType\"],\"TSInferType\":[\"typeParameter\"],\"TSParenthesizedType\":[\"typeAnnotation\"],\"TSTypeOperator\":[\"typeAnnotation\"],\"TSIndexedAccessType\":[\"objectType\",\"indexType\"],\"TSMappedType\":[\"typeParameter\",\"typeAnnotation\"],\"TSLiteralType\":[\"literal\"],\"TSExpressionWithTypeArguments\":[\"expression\",\"typeParameters\"],\"TSInterfaceDeclaration\":[\"id\",\"typeParameters\",\"extends\",\"body\"],\"TSInterfaceBody\":[\"body\"],\"TSTypeAliasDeclaration\":[\"id\",\"typeParameters\",\"typeAnnotation\"],\"TSAsExpression\":[\"expression\",\"typeAnnotation\"],\"TSTypeAssertion\":[\"typeAnnotation\",\"expression\"],\"TSEnumDeclaration\":[\"id\",\"members\"],\"TSEnumMember\":[\"id\",\"initializer\"],\"TSModuleDeclaration\":[\"id\",\"body\"],\"TSModuleBlock\":[\"body\"],\"TSImportEqualsDeclaration\":[\"id\",\"moduleReference\"],\"TSExternalModuleReference\":[\"expression\"],\"TSNonNullExpression\":[\"expression\"],\"TSExportAssignment\":[\"expression\"],\"TSNamespaceExportDeclaration\":[\"id\"],\"TSTypeAnnotation\":[\"typeAnnotation\"],\"TSTypeParameterInstantiation\":[\"params\"],\"TSTypeParameterDeclaration\":[\"params\"],\"TSTypeParameter\":[\"constraint\",\"default\"]}",
    _powerAssertRecorder = function () { function PowerAssertRecorder() { this.captured = []; } PowerAssertRecorder.prototype._capt = function _capt(value, espath) { this.captured.push({ value: value, espath: espath }); return value; }; PowerAssertRecorder.prototype._expr = function _expr(value, source) { var capturedValues = this.captured; this.captured = []; return { powerAssertContext: { value: value, events: capturedValues }, source: source }; }; return PowerAssertRecorder; }();

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/** @test {PNGGenerator} */
describe('PNGGenerator', () => {
  const Module = (0, _rewire.default)('./png-generator.js');
  /** @test {GetRequiredPNGImageSizes} */

  describe('GetRequiredPNGImageSizes', () => {
    it('All', () => {
      var _rec = new _powerAssertRecorder(),
          _rec2 = new _powerAssertRecorder();

      let actual = (0, _pngGenerator.GetRequiredPNGImageSizes)();
      let expected = [16, 24, 32, 48, 57, 64, 72, 96, 120, 128, 144, 152, 195, 228, 256, 512, 1024];

      _powerAssert.default.deepStrictEqual(_rec._expr(_rec._capt(actual, "arguments/0"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 21,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }), _rec2._expr(_rec2._capt(expected, "arguments/1"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 21,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }));
    });
    it('All with filter', () => {
      var _rec3 = new _powerAssertRecorder(),
          _rec4 = new _powerAssertRecorder();

      let actual = (0, _pngGenerator.GetRequiredPNGImageSizes)({
        ico: {
          sizes: [256]
        },
        icns: {
          sizes: [512]
        },
        favicon: {}
      });
      let expected = [16, 24, 32, 48, 57, 64, 72, 96, 120, 128, 144, 152, 195, 228, 256, 512];

      _powerAssert.default.deepStrictEqual(_rec3._expr(_rec3._capt(actual, "arguments/0"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 27,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }), _rec4._expr(_rec4._capt(expected, "arguments/1"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 27,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }));
    });
    it('ICO', () => {
      var _rec5 = new _powerAssertRecorder(),
          _rec6 = new _powerAssertRecorder();

      let actual = (0, _pngGenerator.GetRequiredPNGImageSizes)({
        ico: {}
      });
      let expected = (0, _icoGenerator.GetRequiredICOImageSizes)();

      _powerAssert.default.deepStrictEqual(_rec5._expr(_rec5._capt(actual, "arguments/0"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 33,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }), _rec6._expr(_rec6._capt(expected, "arguments/1"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 33,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }));
    });
    it('ICO with filter', () => {
      var _rec7 = new _powerAssertRecorder(),
          _rec8 = new _powerAssertRecorder();

      let actual = (0, _pngGenerator.GetRequiredPNGImageSizes)({
        ico: {
          sizes: [16, 32, 64]
        }
      });
      let expected = [16, 32, 64];

      _powerAssert.default.deepStrictEqual(_rec7._expr(_rec7._capt(actual, "arguments/0"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 39,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }), _rec8._expr(_rec8._capt(expected, "arguments/1"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 39,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }));
    });
    it('ICNS', () => {
      var _rec9 = new _powerAssertRecorder(),
          _rec10 = new _powerAssertRecorder();

      let actual = (0, _pngGenerator.GetRequiredPNGImageSizes)({
        icns: {}
      });
      let expected = (0, _icnsGenerator.GetRequiredICNSImageSizes)();

      _powerAssert.default.deepStrictEqual(_rec9._expr(_rec9._capt(actual, "arguments/0"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 45,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }), _rec10._expr(_rec10._capt(expected, "arguments/1"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 45,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }));
    });
    it('ICNS with filter', () => {
      var _rec11 = new _powerAssertRecorder(),
          _rec12 = new _powerAssertRecorder();

      let actual = (0, _pngGenerator.GetRequiredPNGImageSizes)({
        icns: {
          sizes: [16, 1024]
        }
      });
      let expected = [16, 1024];

      _powerAssert.default.deepStrictEqual(_rec11._expr(_rec11._capt(actual, "arguments/0"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 51,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }), _rec12._expr(_rec12._capt(expected, "arguments/1"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 51,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }));
    });
    it('Favicon', () => {
      var _rec13 = new _powerAssertRecorder(),
          _rec14 = new _powerAssertRecorder();

      let actual = (0, _pngGenerator.GetRequiredPNGImageSizes)({
        favicon: {}
      });
      let expected = (0, _faviconGenerator.GetRequiredFavoriteImageSizes)();

      _powerAssert.default.deepStrictEqual(_rec13._expr(_rec13._capt(actual, "arguments/0"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 57,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }), _rec14._expr(_rec14._capt(expected, "arguments/1"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 57,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }));
    });
  });
  /** @test {generatePNG} */

  it('generetePNG', () => {
    var _rec15 = new _powerAssertRecorder(),
        _rec16 = new _powerAssertRecorder();

    const generatePNG = Module.__get__('generatePNG');

    const svg = _fs.default.readFileSync('./examples/data/sample.svg');

    (0, _powerAssert.default)(_rec15._expr(_rec15._capt(svg, "arguments/0"), {
      content: "assert(svg)",
      filepath: "src/lib/png-generator.test.js",
      line: 65,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"svg\",\"range\":[7,10]}],\"range\":[0,11]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"svg\",\"range\":[7,10]},{\"type\":{\"label\":\")\"},\"range\":[10,11]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));

    const dir = _util.default.createWorkDir();

    (0, _powerAssert.default)(_rec16._expr(_rec16._capt(dir, "arguments/0"), {
      content: "assert(dir)",
      filepath: "src/lib/png-generator.test.js",
      line: 68,
      ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"dir\",\"range\":[7,10]}],\"range\":[0,11]}",
      tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"dir\",\"range\":[7,10]},{\"type\":{\"label\":\")\"},\"range\":[10,11]}]",
      visitorKeys: _powerAssertVisitorKeys
    }));
    const size = 16;
    return generatePNG(svg, size, dir, new _logger.default()).then(result => {
      var _rec17 = new _powerAssertRecorder();

      (0, _powerAssert.default)(_rec17._expr(_rec17._capt(_rec17._capt(_rec17._capt(result, "arguments/0/left/object").size, "arguments/0/left") === _rec17._capt(size, "arguments/0/right"), "arguments/0"), {
        content: "assert(result.size === size)",
        filepath: "src/lib/png-generator.test.js",
        line: 73,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"arguments\":[{\"type\":\"BinaryExpression\",\"operator\":\"===\",\"left\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"result\",\"range\":[7,13]},\"property\":{\"type\":\"Identifier\",\"name\":\"size\",\"range\":[14,18]},\"computed\":false,\"range\":[7,18]},\"right\":{\"type\":\"Identifier\",\"name\":\"size\",\"range\":[23,27]},\"range\":[7,27]}],\"range\":[0,28]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\"(\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"result\",\"range\":[7,13]},{\"type\":{\"label\":\".\"},\"range\":[13,14]},{\"type\":{\"label\":\"name\"},\"value\":\"size\",\"range\":[14,18]},{\"type\":{\"label\":\"==/!=\"},\"value\":\"===\",\"range\":[19,22]},{\"type\":{\"label\":\"name\"},\"value\":\"size\",\"range\":[23,27]},{\"type\":{\"label\":\")\"},\"range\":[27,28]}]",
        visitorKeys: _powerAssertVisitorKeys
      }));

      _del.default.sync([dir], {
        force: true
      });
    }).catch(err => {
      console.error(err);
      (0, _powerAssert.default)();

      _del.default.sync([dir], {
        force: true
      });
    });
  });
  describe('filterSizes', () => {
    const filterSizes = Module.__get__('filterSizes');

    it('Filter', () => {
      var _rec18 = new _powerAssertRecorder(),
          _rec19 = new _powerAssertRecorder();

      const actual = filterSizes((0, _icnsGenerator.GetRequiredICNSImageSizes)(), [16, 18, 32, 64]);
      const expected = [16, 32, 64];

      _powerAssert.default.deepStrictEqual(_rec18._expr(_rec18._capt(actual, "arguments/0"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 89,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }), _rec19._expr(_rec19._capt(expected, "arguments/1"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 89,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }));
    });
    it('No filter', () => {
      var _rec20 = new _powerAssertRecorder(),
          _rec21 = new _powerAssertRecorder();

      const actual = filterSizes((0, _icnsGenerator.GetRequiredICNSImageSizes)());
      const expected = [16, 32, 64, 128, 256, 512, 1024];

      _powerAssert.default.deepStrictEqual(_rec20._expr(_rec20._capt(actual, "arguments/0"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 95,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }), _rec21._expr(_rec21._capt(expected, "arguments/1"), {
        content: "assert.deepStrictEqual(actual, expected)",
        filepath: "src/lib/png-generator.test.js",
        line: 95,
        ast: "{\"type\":\"CallExpression\",\"callee\":{\"type\":\"MemberExpression\",\"object\":{\"type\":\"Identifier\",\"name\":\"assert\",\"range\":[0,6]},\"property\":{\"type\":\"Identifier\",\"name\":\"deepStrictEqual\",\"range\":[7,22]},\"computed\":false,\"range\":[0,22]},\"arguments\":[{\"type\":\"Identifier\",\"name\":\"actual\",\"range\":[23,29]},{\"type\":\"Identifier\",\"name\":\"expected\",\"range\":[31,39]}],\"range\":[0,40]}",
        tokens: "[{\"type\":{\"label\":\"name\"},\"value\":\"assert\",\"range\":[0,6]},{\"type\":{\"label\":\".\"},\"range\":[6,7]},{\"type\":{\"label\":\"name\"},\"value\":\"deepStrictEqual\",\"range\":[7,22]},{\"type\":{\"label\":\"(\"},\"range\":[22,23]},{\"type\":{\"label\":\"name\"},\"value\":\"actual\",\"range\":[23,29]},{\"type\":{\"label\":\",\"},\"range\":[29,30]},{\"type\":{\"label\":\"name\"},\"value\":\"expected\",\"range\":[31,39]},{\"type\":{\"label\":\")\"},\"range\":[39,40]}]",
        visitorKeys: _powerAssertVisitorKeys
      }));
    });
  });
});